@@ -149,6 +149,7 @@ PBA <- function(f.root, interval, ..., p = .6,
     logq <- log(1-p)
 
     dots <- list(...)
+    lastSolve <- NULL
     FromSimSolve <- .SIMDENV$FromSimSolve
     if(!is.null(FromSimSolve)){
         family <- FromSimSolve$family
@@ -171,6 +172,7 @@ PBA <- function(f.root, interval, ..., p = .6,
         glmpred.last <- glmpred <- glmpred0 <- c(NA, NA)
         k.success <- FromSimSolve$k.success
         k.successes <- 0L
+        lastSolve <- FromSimSolve$lastSolve
     } else{
         interpolate <- FALSE
         interpolate.burnin <- NULL
@@ -210,6 +212,20 @@ PBA <- function(f.root, interval, ..., p = .6,
     }
     glmpred.converged <- FALSE
     iter <- 0L
+    if(!is.null(lastSolve)){
+        # continuation
+        root_info <- attr(lastSolve, 'root')[[1]]
+        iter <- root_info$iter
+        fx <- log(root_info$fx)
+        x <- root_info$x
+        medhistory <- root_info$medhistory
+        roothistory <- root_info$roothistory
+        if(length(medhistory) == maxiter)
+            stop('Please increase the maximum number of iterations', call.=FALSE)
+        roothistory <- c(roothistory, rep(NA, maxiter - length(medhistory)))
+        medhistory <- c(medhistory, numeric(maxiter - length(medhistory)))
+        .SIMDENV$stored_medhistory <- root_info$medhistory
+    }
 
     while(TRUE){
         iter <- iter + 1L
@@ -344,7 +360,7 @@ PBA <- function(f.root, interval, ..., p = .6,
     if(verbose)
         cat("\n")
     fx <- exp(fx) / sum(exp(fx)) # normalize final result
-    medhistory <- medhistory[1L:(iter-1L)]
+    medhistory <- medhistory[1L:iter]
     # BI <- belief_interval(x, fx, CI=CI)
     root <- if(!interpolate || is.na(glmpred0[1]))
         medhistory[length(medhistory)] else glmpred0[1L]
@@ -352,7 +368,10 @@ PBA <- function(f.root, interval, ..., p = .6,
         warning('Interpolation model failed; root set to last PBA estimate',
                 call.=FALSE)
     ret <- list(iter=iter, root=root, terminated_early=converged, integer=integer,
-                e.froot=e.froot, x=x, fx=fx, medhistory=medhistory,
+                e.froot=e.froot, x=x, fx=fx,
+                medhistory=medhistory, roothistory=roothistory[1:length(medhistory)],
+                stored_results=.SIMDENV$stored_results,
+                stored_history=.SIMDENV$stored_history,
                 time=as.numeric(proc.time()[3L]-start_time),
                 burnin=interpolate.burnin, b=dots$b,
                 predCIs=predCIs[-1L], predCIs_root=predCIs_root)
@@ -420,8 +439,10 @@ getMedian <- function(fx, x){
     ret[length(ret)]
 }
 
-bool.f <- function(f.root, median, integer, .SIMDENV, ...){
-    val <- valp <- f.root(median, ...)
+bool.f <- function(f.root, median, integer, .SIMDENV = NULL, ...){
+    val <- valp <- if(!is.null(.SIMDENV$FromSimSolve))
+        f.root(median, integer=integer, ...)
+    else f.root(median, ...)
     if(integer && !is.null(.SIMDENV$FromSimSolve) && .SIMDENV$FromSimSolve$bolster){
         if(!all(is.na(.SIMDENV$stored_medhistory))){
             whc <- which(median == .SIMDENV$stored_medhistory)
