@@ -6,8 +6,10 @@
 #'
 #' @param object object returned from \code{\link{runSimulation}}
 #'
-#' @param what character indicating what information to extract. Possible inputs
-#'   include \code{'errors'} to return a \code{tibble} object containing counts of any
+#' @param what character vector indicating what information to extract, written in agnostic casing
+#'   (e.g., \code{'ERRORS'} and \code{'errors'} are equivalent).
+#'
+#'   Possible inputs include \code{'errors'}  to return a \code{tibble} object containing counts of any
 #'   error messages, \code{'warnings'} to return a \code{data.frame} object containing
 #'   counts of any warning messages, \code{'seeds'}  for the specified random number
 #'   generation seeds,  \code{'Random.seeds'} for the complete list of
@@ -17,9 +19,8 @@
 #'   to extract the associated \code{.Random.seed} values associated with the ERROR/WARNING messages,
 #'   \code{'results'} to extract the simulation results if the option \code{store_results} was passed to
 #'   \code{\link{runSimulation}}, \code{'filename'} and \code{'save_results_dirname'} for extracting
-#'   the saved file/directory name information (if used),
-#'   and \code{'summarise'} if the \code{\link{Summarise}}
-#'   definition returned a named \code{list} rather than a named numeric vector.
+#'   the saved file/directory name information (if used), \code{'functions'} to extract the defined functions
+#'   used in the experiment, and \code{'design'} to extract the original design object
 #'
 #'   Note that \code{'warning_seeds'} are not stored automatically in
 #'   simulations and require passing \code{store_warning_seeds = TRUE} to \code{\link{runSimulation}}.
@@ -99,8 +100,8 @@ SimExtract <- function(object, what, fuzzy = TRUE, append = TRUE){
     } else if(what == 'errors'){
         err <- extract_errors(object, fuzzy=fuzzy)
         if(length(err) && append) cbind(Design, err) else err
-    } else if(what == 'summarise'){
-        extract_summarise(object)
+    } else if(what == 'functions'){
+        extract_functions(object)
     }  else if(what == 'seeds'){
         extract_seeds(object)
     } else if(what == 'random.seeds'){
@@ -181,13 +182,9 @@ extract_seeds <- function(object){
     ret
 }
 
-extract_summarise <- function(object){
+extract_functions <- function(object){
     extra_info <- attr(object, 'extra_info')
-    Design <- SimExtract(object, 'Design')
-    nms <- apply(Design, 1L, function(x)
-        paste0(colnames(Design), "=", x, collapse = ' ; '))
-    ret <- extra_info$summarise_list
-    names(ret) <- nms
+    ret <- extra_info$functions
     ret
 }
 
