@@ -127,6 +127,9 @@
 #'   independently specified termination criteria in \code{control}. See
 #'   \code{\link{timeFormater}} for alternative specifications
 #'
+#' @param lastSolve stub for \code{Spower} package; not to be used by
+#'   front-end users
+#'
 #' @param control a \code{list} of the algorithm control parameters. If not specified,
 #'   the defaults described below are used.
 #'
@@ -473,8 +476,8 @@ SimSolve <- function(design, interval, b, generate, analyse, summarise,
                      ncores = parallelly::availableCores(omit = 1L),
                      type = ifelse(.Platform$OS.type == 'windows', 'PSOCK', 'FORK'),
                      maxiter = 100L, check.interval = TRUE,
-                     verbose = TRUE, control = list(),
-                     predCI = .95, predCI.tol = NULL, ...){
+                     predCI = .95, predCI.tol = NULL, lastSolve = NULL,
+                     verbose = TRUE, control = list(), ...){
 
     # robust <- FALSE
     org.opts <- options()
@@ -572,7 +575,7 @@ SimSolve <- function(design, interval, b, generate, analyse, summarise,
         if(store){
             pick <- min(which(sapply(.SIMDENV$stored_results, is.null)))
             .SIMDENV$stored_results[[pick]] <- ret$summary_results
-            .SIMDENV$stored_medhistory[[pick]] <- x
+            .SIMDENV$stored_medhistory[pick] <- x
             .SIMDENV$stored_history[[pick]] <-
                 data.frame(y=val, x=x, reps=replications)
         }
@@ -645,7 +648,7 @@ SimSolve <- function(design, interval, b, generate, analyse, summarise,
             utils::flush.console()
         }
         if(verbose) cat("\n")
-
+        dots <- list(...)
         .SIMDENV$stored_results <- vector('list', maxiter)
         .SIMDENV$stored_medhistory <- rep(NA, maxiter)
         .SIMDENV$stored_history <- vector('list', maxiter)
@@ -665,7 +668,17 @@ SimSolve <- function(design, interval, b, generate, analyse, summarise,
                                       # robust = robust,
                                       predCI = c((1-predCI)/2, predCI + (1-predCI)/2),
                                       predCI.tol=predCI.tol,
-                                      interpolate.burnin=burnin.iter)
+                                      interpolate.burnin=burnin.iter,
+                                      lastSolve=lastSolve)
+        if(!is.null(lastSolve)){
+            root_info <- attr(lastSolve, 'root')[[1]]
+            len <- length(root_info$stored_results)
+            if(len > maxiter)
+                stop('Please increase maxiter', call.=FALSE)
+            .SIMDENV$stored_results[1:len] <- root_info$stored_results
+            .SIMDENV$stored_history[1:len] <- root_info$stored_history
+        }
+        on.exit(.SIMDENV <- NULL, add=TRUE)
         if(method == 'ProBABLI'){
             roots[[i]] <- try(PBA(root.fun, interval=interval[i, , drop=TRUE], b=b,
                                   design.row=as.data.frame(design[i,]),
