@@ -158,9 +158,9 @@
 #'   each \code{design} condition. Return of this function, in order
 #'   of increasing complexity, should be: a named numeric vector or \code{data.frame}
 #'   with one row, a \code{matrix} or \code{data.frame} with more than one row, and,
-#'   failing these more atomic types, a named \code{list}. For summary objects that
-#'   are not easily appended to the original \code{design} object use
-#'   \code{\link{SimExtract}} with the option \code{what = 'summarise'}.
+#'   failing these more atomic types, a named \code{list}. When a \code{list} is returned
+#'   the final simulation object will contain a column \code{SUMMARISE} containing the
+#'   summary results for each respective condition
 #'
 #'   Note that unlike the Generate and Analyse
 #'   steps, the Summarise portion is not as important to perfectly organize
@@ -237,11 +237,12 @@
 #'
 #' @param packages a character vector of external packages to be used during the simulation (e.g.,
 #'   \code{c('MASS', 'extraDistr', 'simsem')} ). Use this input when running code in
-#'   parallel to use non-standard functions from additional packages,
-#'   otherwise the functions must be made available by using explicit
-#'   \code{\link{library}} or \code{\link{require}} calls within the provided simulation functions.
-#'   Alternatively, functions can be called explicitly without attaching the package
-#'   with the \code{::} operator
+#'   parallel to use non-standard functions from additional packages. Note that any previously attached
+#'   packages explicitly loaded via \code{\link{library}} or \code{\link{require}}
+#'   will be automatically added to this list, provided that they are visible
+#'   in the \code{otherPkgs} element
+#'   from \code{\link[utils]{sessionInfo}}. Alternatively, functions can be called
+#'   explicitly without attaching the package with the \code{::} operator
 #'   (e.g., \code{extraDistr::rgumbel()})
 #'
 #' @param beep logical; call the \code{beepr} package when the simulation is completed?
@@ -1259,7 +1260,9 @@ runSimulation <- function(design, replications, generate, analyse, summarise,
         parallel <- FALSE
         verbose <- FALSE
     }
-    packages <- c('SimDesign', packages)
+    packages <- unique(c(packages, 'SimDesign'))
+    if(all(names(utils::sessionInfo()$otherPkgs) != 'future'))
+        packages <- unique(c(packages, names(utils::sessionInfo()$otherPkgs)))
     char_functions <- deparse(substitute(Functions[[i]]))
     if(any(grepl('browser\\(', char_functions))){
         if(verbose && parallel)
@@ -1663,10 +1666,14 @@ runSimulation <- function(design, replications, generate, analyse, summarise,
     if(!is.null(Final$REPLICATIONS)) replications <- Final$REPLICATIONS
     Final$SIM_TIME <- Final$ID <- Final$COMPLETED <-
         Final$REPLICATIONS <- Final$REPLICATION <- Final$FATAL_TERMINATION <- NULL
+    SUMMARISE <- if(any(!sapply(summarise_list, is.null))){
+        summarise_list
+    } else rep(NA, nrow(Final))
     Final <- data.frame(Final, FATAL_TERMINATION,
                         REPLICATIONS=replications, SIM_TIME=SIM_TIME,
                         RAM_USED=memory_used,
                         COMPLETED, check.names=FALSE, stringsAsFactors=FALSE)
+    if(!all(is.na(SUMMARISE))) Final$SUMMARISE <- SUMMARISE
     if(all(is.na(Final$FATAL_TERMINATION))) Final$FATAL_TERMINATION <- NULL
     if(is.null(Final$SEED)) Final$SEED <- NA
     if(!is.null(seed)) Final$SEED <- seed
@@ -1718,9 +1725,8 @@ runSimulation <- function(design, replications, generate, analyse, summarise,
                                       error_seeds=dplyr::as_tibble(error_seeds),
                                       warning_seeds=dplyr::as_tibble(warning_seeds),
                                       stored_results = if(store_results) stored_Results_list else NULL,
-                                      summarise_list=summarise_list, Design.ID=Design.ID)
-    if(!is.null(summarise_list[[1L]]) && verbose)
-        message('Note: To extract Summarise() results use SimExtract(., what = \'summarise\')')
+                                      Design.ID=Design.ID,
+                                      functions=list(Generate=Generate, Analyse=Analyse, Summarise=Summarise))
     if(dummy_run) Final$dummy_run <- NULL
     class(Final) <- c('SimDesign', class(Final))
     if(!is.null(filename)){ #save file
