@@ -23,8 +23,8 @@
 #'   the relative bias statistic (i.e., divide the bias by the value
 #'   in \code{parameter}; note that multiplying this by 100 gives the "percent bias" measure, or
 #'   if Type I error rates (\eqn{\alpha}) are supplied will result in the "percentage error"),
-#'   \code{'abs_relative'} computes the relative bias but the absolute values of the parameters
-#'   are used in the denominator rather than the (potentially) signed input values,
+#'   \code{'abs_relative'} computes the relative bias for each replication independently, takes the
+#'   absolute value of each term, then computes the mean estimate,
 #'   and \code{'standardized'} computes the standardized bias estimate
 #'   (standard bias divided by the standard deviation of the sample estimates)
 #'
@@ -64,6 +64,7 @@
 #' bias(samp, pop)
 #' bias(samp, pop, type = 'relative')
 #' bias(samp, pop, type = 'standardized')
+#' bias(samp, pop, type = 'abs_relative')
 #'
 #' dev <- samp - pop
 #' bias(dev)
@@ -121,7 +122,11 @@ bias <- function(estimate, parameter = NULL, type = 'bias', abs = FALSE,
     stopifnot(is.matrix(estimate))
     stopifnot(type %in% c('bias', 'standardized', 'relative', 'abs_relative'))
     n_col <- ncol(estimate)
-    if(type == "relative") stopifnot(!is.null(parameter))
+    if(type %in% c("relative", 'abs_relative')){
+        stopifnot(!is.null(parameter))
+        if(any(parameter == 0))
+            stop('relative measures cannot have any parameter = 0', call.=FALSE)
+    }
     if(is.null(parameter)) parameter <- 0
     if(is.data.frame(parameter)) parameter <- unlist(parameter)
     stopifnot(is.vector(parameter))
@@ -131,7 +136,7 @@ bias <- function(estimate, parameter = NULL, type = 'bias', abs = FALSE,
         stopifnot(ncol(estimate) == length(parameter))
     diff <- t(t(estimate) - parameter)
     ret <- if(type == 'relative') rowMeans(t(diff) / parameter)
-        else if(type == 'abs_relative') rowMeans(t(diff) / abs(parameter))
+        else if(type == 'abs_relative') rowMeans(abs(t(diff) / parameter))
         else if(type == 'standardized') colMeans(diff) / colSDs(estimate)
         else colMeans(diff)
     if(abs) ret <- abs(ret)
