@@ -66,10 +66,31 @@ test_that('SimDesign', {
         return(ret)
     }
 
+    mycollect_list <-  function(condition, results, fixed_objects){
+
+        #find results of interest here
+        nms <- c('welch', 'independent')
+        lessthan.05 <- EDR(results[,nms], alpha = .05)
+
+        # return the results that will be appended to the Design input
+        ret <- list(lessthan.05=lessthan.05, something=42)
+        return(ret)
+    }
+
     Final <- runSimulation(Design, generate=mysim, analyse=mycompute, summarise=mycollect,
                            replications = 2, parallel=FALSE, save=FALSE, verbose = FALSE)
     expect_is(Final, 'data.frame')
 
+    # list in summarise
+    Final <- runSimulation(Design, generate=mysim, analyse=mycompute, summarise=mycollect_list,
+                           replications = 2, parallel=FALSE, save=FALSE, verbose = FALSE)
+    expect_is(Final, 'data.frame')
+    expect_is(Final$SUMMARISE, 'list')
+
+    # resummarise list info
+    resum <- reSummarise(mycollect_list, results=Final)
+    expect_is(resum$SUMMARISE, 'list')
+
     mycollect <-  function(condition, results, fixed_objects){
 
         # return the results that will be appended to the Design input
@@ -555,9 +576,7 @@ test_that('SimDesign', {
     res <- runSimulation(design=Design, replications=10, generate=generate,
                          analyse=analyse, summarise=summarise, fixed_objects=fo,
                          packages = 'purrr', verbose=FALSE)
-
-    lst <- SimExtract(res, 'summarise')
-    expect_equal(names(lst), c("N=250", "N=500"))
+    expect_is(res$SUMMARISE, 'list')
 
     ## modular
     Design <- createDesign(factor1 = 1,
